require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_wsmanlistener',
  dscmeta_resource_friendly_name: 'WSManListener',
  dscmeta_resource_name: 'DSR_WSManListener',
  dscmeta_module_name: 'WSManDsc',
  dscmeta_module_version: '2.2.0.84',
  docs: 'The DSC WSManListener resource type.
         Automatically generated from version 2.2.0.84',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_dn: {
      type: 'Optional[String]',
      desc: 'This is a Distinguished Name component that will be used to identify the certificate to use for the HTTPS WS-Man Listener if a thumbprint is not specified.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Enum['Present', 'Absent']",
      desc: 'Specifies whether the WS-Man Listener should exist.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_urlprefix: {
      type: 'Optional[String]',
      desc: 'The URL Prefix of the existing WS-Man Listener.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_issuer: {
      type: 'Optional[String]',
      desc: 'The Issuer of the certificate to use for the HTTPS WS-Man Listener if a thumbprint is not specified.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_address: {
      type: 'Optional[String]',
      desc: 'The Address that the WS-Man Listener will be bound to. The default is * (any address).',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_transport: {
      type: "Enum['HTTP', 'HTTPS']",
      desc: 'The transport type of WS-Man Listener.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_hostname: {
      type: 'Optional[String]',
      desc: 'The host name that a HTTPS WS-Man Listener will be bound to. If not specified it will default to the computer name of the node.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: 'The Thumbprint of the certificate to use for the HTTPS WS-Man Listener.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: 'Optional[Boolean]',
      desc: 'Returns true if the existing WS-Man Listener is enabled.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_matchalternate: {
      type: 'Optional[Boolean]',
      desc: 'Should the FQDN/Name be used to also match the certificate alternate subject for an HTTPS WS-Man Listener if a thumbprint is not specified.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_subjectformat: {
      type: "Optional[Enum['Both', 'FQDNOnly', 'NameOnly']]",
      desc: 'The format used to match the certificate subject to use for an HTTPS WS-Man Listener if a thumbprint is not specified.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_port: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'The port the WS-Man Listener should use. Defaults to 5985 for HTTP and 5986 for HTTPS listeners.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
  },
)
